import click

def package_installation_hint(package_name: str):
    OKGREEN = '\033[92m'
    ENDC = '\033[0m'
    BOLD = "\033[1m"
    print(f"\t{BOLD}Please install:{ENDC}\t{OKGREEN}{package_name}{ENDC}{BOLD}{ENDC}")

@click.group()
@click.pass_context
def cli(
    ctx: click.Context
):
    pass

@cli.group(name='delta')
def delta_cmd():
    """Delta server run command"""
    pass

@delta_cmd.command("server")
@click.option("--host","-h",
              type=click.STRING,
              default="127.0.0.1",
              show_default=True,
              help='Host for the feature server.'
              )
@click.option("--port","-p",
              type=click.INT,
              default=8080,
              show_default=True,
              help='Port for the feature server.'
              )
@click.option("--filename","-f",
              type=click.STRING,
              default="config.yaml",
              show_default=True,
              help='Configuration filename for the delta lake.'
              )
@click.option("--log-level",
              type=click.STRING,
              default="error",
              show_default=True,
              help='Log level for the feature server. One of: debug, info, error, warn'
              )
@click.pass_context
def delta_server_command(
    ctx: click.Context,
    host: str,
    port: int,
    filename: str,
    log_level: str,
):
    """Start rust delta."""
    try:
        import yummy_delta
        yummy_delta.run(filename, host, port, log_level)
    except ModuleNotFoundError:
        package_installation_hint("yummy[delta]")

@delta_cmd.command("apply")
@click.option("--filename","-f",
              type=click.STRING,
              default="apply.yaml",
              show_default=True,
              help='Configuration filename for the delta lake.'
              )
@click.pass_context
def delta_apply_command(
    ctx: click.Context,
    filename: str,
):
    """Start rust apply delta."""
    try:
        import yummy_delta
        yummy_delta.run_apply(filename)
    except ModuleNotFoundError:
        package_installation_hint("yummy[delta]")


@delta_cmd.command(name='get')
@click.argument('otype', nargs=1)
@click.option("--filename","-f",
              type=click.STRING,
              default="config.yaml",
              show_default=True,
              help='Configuration filename for the delta lake.'
              )
@click.option("--store","-s",
              type=click.STRING,
              required=False,
              help='Store name'
              )
@click.option("--table","-t",
              type=click.STRING,
              required=False,
              help='Table name'
              )
@click.pass_context
def delta_get_command(
    ctx: click.Context,
    otype: str,
    filename: str,
    store: str,
    table: str,
):
    """Delta get command"""
    try:
        import yummy_delta

        if otype == "stores":
            yummy_delta.run_pprint_stores(filename)
        elif otype == "tables":
            yummy_delta.run_pprint_tables(filename, store)
        elif otype == "table":
            yummy_delta.run_pprint_table(filename, store, table)

    except ModuleNotFoundError:
        package_installation_hint("yummy[delta]")


@cli.group(name='features')
def features_cmd():
    """Features related commands"""
    pass

@features_cmd.command("serve")
@click.option("--host","-h",
              type=click.STRING,
              default="127.0.0.1",
              show_default=True,
              help='Host for the feature server.'
              )
@click.option("--port","-p",
              type=click.INT,
              default=6566,
              show_default=True,
              help='Port for the feature server.'
              )
@click.option("--filename","-f",
              type=click.STRING,
              default="feature_store.yaml",
              show_default=True,
              help='Configuration filename for the feature server.'
              )
@click.option("--log-level",
              type=click.STRING,
              default="error",
              show_default=True,
              help='Log level for the feature server. One of: debug, info, error, warn'
              )
@click.pass_context
def features_serve_command(
    ctx: click.Context,
    host: str,
    port: int,
    filename: str,
    log_level: str,
):
    """Start rust feature server."""
    try:
        import yummy_features
        yummy_features.serve(filename, host, port, log_level)
    except ModuleNotFoundError:
        package_installation_hint("yummy[features]")



@cli.group(name='models')
def models_cmd():
    """Models related commands"""
    pass

@models_cmd.command("serve")
@click.option("--host","-h",
              type=click.STRING,
              default="127.0.0.1",
              show_default=True,
              help='Host for the feature server.'
              )
@click.option("--port","-p",
              type=click.INT,
              default=5000,
              show_default=True,
              help='Port for the feature server.'
              )
@click.option("--model-uri","-m",
              type=click.STRING,
              required=True,
              help='Local model path.'
              )
@click.option("--log-level",
              type=click.STRING,
              default="error",
              show_default=True,
              help='Log level for the feature server. One of: debug, info, error, warn'
              )
@click.pass_context
def models_serve_command(
    ctx: click.Context,
    host: str,
    port: int,
    model_uri: str,
    log_level: str,
):
    """Start mlflow model server."""
    try:
        import yummy_mlflow
        yummy_mlflow.serve(model_uri, host, port, log_level)
    except ModuleNotFoundError:
        package_installation_hint("yummy[mlflow]")


if __name__ == '__main__':
    cli()



from setuptools import find_packages, setup

NAME = "yummy"
REQUIRES_PYTHON = ">=3.7.0"

INSTALL_REQUIRE = [
    "click>=7.0.0"
]

YUMMY_MLFLOW_REQUIRE = [ "yummy-mlflow~=0.0.9" ]

YUMMY_DELTA_REQUIRE = [ "yummy-delta~=0.0.9" ]

YUMMY_FEATURES_REQUIRE = [ "yummy-features~=0.0.9" ]

FEAST_REQUIRE = [
    "feast~=0.34.1",
    "polars>=0.13.18",
    "deltalake>=0.5.6",
]

DASK_REQUIRE = [
    "dask[distributed]>=2021.11.0",
]

RAY_REQUIRE = DASK_REQUIRE + [
    "ray[default,data]>=1.9.1",
]

SPARK_REQUIRE = [
    "pyspark>=3.0.0",
]

#DEV_REQUIRE = RAY_REQUIRE + \
#    SPARK_REQUIRE + \
#    FEAST_REQUIRE + \
#    YUMMY_MLFLOW_REQUIRE + \
#    YUMMY_DELTA_REQUIRE + \
#    YUMMY_FEATURES_REQUIRE + [
#    "flake8",
#    "black==21.10b0",
#    "isort>=5",
#    "mypy>=0.790",
#    "build>=0.7.0",
#    "twine>=3.4.2",
#    "pytest>=6.0.0",
#]

DEV_REQUIRE = [
    "scikit-learn>=1.0.0",  
    "filelock>=3.0.0"
    "flake8>=6.0.0,<6.1.0",
    "black>=22.6.0,<23",
    "isort>=5,<6",
    "mypy>=0.981,<0.990",
    "build>=0.7.0",
    "twine>=3.4.2",
    "pytest>=6.0.0,<8",
]


setup(
    name=NAME,
    version="0.0.10",
    author="Qooba",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    python_requires=REQUIRES_PYTHON,
    url="https://github.com/yummyml/yummy",
    packages=find_packages(exclude=["test*", "feature_repo*"]),
    install_requires=INSTALL_REQUIRE,
    extras_require={
        "delta": YUMMY_DELTA_REQUIRE,
        "features": YUMMY_FEATURES_REQUIRE,
        "mlflow": YUMMY_MLFLOW_REQUIRE,
        "feast": FEAST_REQUIRE,
        "dask": DASK_REQUIRE,
        "ray": RAY_REQUIRE,
        "spark": SPARK_REQUIRE,
        "dev": DEV_REQUIRE,
    },
    keywords=("feast featurestore polars dask ray pyspark offlinestore"),
    license='Apache License, Version 2.0',
    classifiers=[
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
    entry_points={"console_scripts": ["yummy=yummy.cli:cli"]},
)
